@@ -4,7 +4,10 @@ set -eu
 # This script tests if webpack ast is identical to webpack ast produced by acorn,
 # by running webpack via next.js
 
-UPDATE=1 cargo test
+export RUST_BACKTRACE=1
+
+cargo test --no-run
+UPDATE=1 cargo test -q
 
 (cd next.js/packages/next-swc && yarn build-native)
 
